Lua_CollectionDetailPanel = class("Lua_CollectionDetailPanel", Lua_DisplayObject);
function Lua_CollectionDetailPanel:ctor(p)
	self:superCall("ctor", p, "CollectionDetailPanel_skin");
end

function Lua_CollectionDetailPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.posY = 0;
	self.showItemList = {};
end

function Lua_CollectionDetailPanel:setData(initInfo)
	self.initInfo = initInfo;
	if type(initInfo) == "table" then
		if initInfo.collection_item_id ~= nil then
			self.collectionVo = Lua_ToolVo.createToolVo(initInfo.collection_item_id);
			self.collectionVo:fromServer(initInfo);
		else
			self.collectionVo = DataCenter.collectionData:getCollectionVo(initInfo.id);
			if self.collectionVo == nil then -- 功能未开启
				self.collectionVo = Lua_ToolVo.createToolVo(initInfo.id);
			end
		end
	elseif type(initInfo) == "number" then
		self.collectionVo = DataCenter.collectionData:getCollectionVo(initInfo);
	end

	self.posY = 0;
	self:updateCollectionDesInfo();
end

function Lua_CollectionDetailPanel:updateCollectionDesInfo()
	self.desTxt.text = self.collectionVo.des;
	self.desTxt:resetSize();

	local info = self.collectionVo.target_value;
	local targetValue = getConfig(info[1], info[2], info[3]);
	self.tipsTxt.text = LanUtil.formateStr(self.collectionVo.task_des, numberTrans(self.collectionVo.obtain_progress), numberTrans(targetValue));
	self.tipsTxt:setLocation(0, -self.desTxt.height - 40);
	self.tipsTxt:resetSize();

	if type(self.initInfo) == "table" then -- 聊天场景和道具tips
		self.tipsTxt:setEnable(false);
		self.propertyObj:SetActive(true);
		self:setPropertyInfo();
	else -- 藏品柜查看
		if self.collectionVo.is_have == 0 then -- 未拥有
			self.posY = self.tipsTxt.posY - self.tipsTxt.height - 5;
			self.tipsTxt:setEnable(true);
			self.propertyObj:SetActive(false);
		else
			self.tipsTxt:setEnable(false);
			self.propertyObj:SetActive(true);
			self:setPropertyInfo();
		end
	end
end

function Lua_CollectionDetailPanel:setPropertyInfo()
	self:setCommonProperty();
	self:setChangeProperty();
	self:setOtherProperty();
end

function Lua_CollectionDetailPanel:createCellItem(data, itemType, style)
	local item;
	if itemType == 1 then
		item = Lua_CollectionDesItem.new(self.propertyObj);
		item:setShowStyle(style);
	elseif itemType == 2 then
		item = Lua_CollectionAttrItem.new(self.propertyObj);
	elseif itemType == 3 then
		item = Lua_PropertyDesItem.new(self.propertyObj);
	end
	item:setData(data);
	item:setEnable(true);

	if self.showItemList[itemType] == nil then
		self.showItemList[itemType] = Array()
	end
	self.showItemList[itemType]:add(item);
	return item;
end

-- 普通属性
function Lua_CollectionDetailPanel:setCommonProperty()
	self.posY = self.desTxt.posY - self.desTxt.height - 15;
	local item = self:createCellItem(LanUtil.getValue(460004), 1, 1);
	item:setLocation(0, self.posY);

	local configArr = self.collectionVo.configArr;
	for i = 1, configArr:getSize() do
		if configArr[i].normal_prop ~= nil then
			self.posY = self.posY - item:getHeight();
			item = self:createCellItem(configArr[i].normal_desc, 1, 2);
			item:setLocation(0, self.posY);

			self.posY = self.posY - item:getHeight();
			item = self:createCellItem(configArr[i].normal_prop, 2);
			item:setLocation(0, self.posY);
		end
	end
	self.posY = self.posY - item:getHeight();
end

-- 成长属性
function Lua_CollectionDetailPanel:setChangeProperty()
	local configArr = self.collectionVo.configArr;
	local tag, changeIdx = self.collectionVo:changeInfo();
	if tag == 2 then
		local item = self:createCellItem(LanUtil.getValue(460005), 1, 1);
		item:setLocation(0, self.posY);
		
		local str;
		local singleStr
		local progressStr;
		local info;
		local targetValue;
		for i = 1, changeIdx do
			self.posY = self.posY - item:getHeight();

			singleStr, progressStr = self:getTheDesStr(configArr[i].prop, self.collectionVo.grow_progress);
			if type(self.initInfo) == "table" then -- 聊天场景和道具tips
				str = configArr[i].title_desc2 .. "，" .. configArr[i].change_desc .. "：" .. singleStr;
			else
				str = configArr[i].title_desc .. "，" .. configArr[i].change_desc .. "：" .. singleStr;
			end
			item = self:createCellItem(str, 3);
			item:setLocation(0, self.posY);

			-- 道具tips不显示
			if not (type(self.initInfo) == "table" and self.initInfo.isShowInfo == false) then
				self.posY = self.posY - item:getHeight();

				info = getConfig("total_task", configArr[i].grow_cond_id);
				targetValue = info.client_condition == nil and info.progress or getConfig(info.client_condition[1], info.progress, info.client_condition[2]);
				item = self:createCellItem(LanUtil.formateStr(460006, self.collectionVo.grow_progress, targetValue / configArr[i].each), 3);
				item:setLocation(0, self.posY);

				self.posY = self.posY - item:getHeight();
				item = self:createCellItem(LanUtil.formateStr(460007, progressStr), 3);
				item:setLocation(0, self.posY);
			end
		end
		self.posY = self.posY - item:getHeight();
	end
end

-- 附加属性
function Lua_CollectionDetailPanel:setOtherProperty()
	local configArr = self.collectionVo.configArr;
	local tag, changeIdx = self.collectionVo:changeInfo();
	local startIdx = tag == 1 and 1 or changeIdx + 1;
	if startIdx <= configArr:getSize() then
		local str = "";
		for i = startIdx, configArr:getSize() do
			str = str .. configArr[i].other_desc .. "：" .. configArr[i].other_value .. "%";
			if i ~= configArr:getSize() then
				str = str .. "\n";
			end
		end

		local item = self:createCellItem(LanUtil.getValue(460008), 1, 1);
		item:setLocation(0, self.posY);
		self.posY = self.posY - item:getHeight();

		item = self:createCellItem(str, 3);
		item:setLocation(0, self.posY);
		self.posY = self.posY - item:getHeight();
	end
end

function Lua_CollectionDetailPanel:getTheDesStr(attrDic, progress)
	local vo;
	local str = "";
	local progressStr = "";
	for k,v in pairs(attrDic) do
		vo = DataCenter.attributesUtil:createAttrVo(k);
		str = str .. vo.show_name .. "+" .. v .. " ";
		progressStr = progressStr .. vo.show_name .. "+" .. v * progress .. " ";
	end
	return str, progressStr;
end

function Lua_CollectionDetailPanel:getWidth()
	return 360;
end

function Lua_CollectionDetailPanel:getHeight()
	return self.desTxt.posY - self.posY;
end

function Lua_CollectionDetailPanel:dispose()
	for _, itemArr in pairs(self.showItemList) do
		itemArr:dispose();
		itemArr:clear();
	end
	self.showItemList = nil;
	self.collectionVo = nil;
	self:superCall("dispose");
end










-- 标题描述
Lua_CollectionDesItem = class("Lua_CollectionDesItem", Lua_DisplayObject);
function Lua_CollectionDesItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_CollectionDesItem:buildShowItem()
	self:superCall("buildShowItem");

	self.desTxt = UICreate.createLabel(self.content, "", 0, 0, 360, 0, 22);
	self.desTxt.pivot = Lua_WindowUtil.getPivot(1);
	self.desTxt.fontName = Lua_MyUISettings.huakangFontName;
	self.desTxt.alignmentValue = 0;
	self.desTxt.verticalOverflowValue = 1;
	self.desTxt.colorStr = Lua_ColorDefine.transColorStr("CEBEA4");
end

function Lua_CollectionDesItem:setShowStyle(showStyle)
	if showStyle == 1 then
		self.desTxt.fontName = Lua_MyUISettings.huakangFontName;
		self.desTxt.colorStr = Lua_ColorDefine.transColorStr("CEBEA4");
	elseif showStyle == 2 then
		self.desTxt.fontName = Lua_MyUISettings.defaultFontName;
		self.desTxt.colorStr = Lua_ColorDefine.transColorStr("797878");
	end
end

function Lua_CollectionDesItem:setData(data)
	if data == nil then
		return;
	end

	self.desTxt.text = data;
	self.desTxt:resetSize();
end

function Lua_CollectionDesItem:getHeight()
	return self.desTxt.height + 10;
end

function Lua_CollectionDesItem:dispose()
	if self.desTxt ~= nil then
		self.desTxt:dispose();
		self.desTxt = nil;
	end
	self:superCall("dispose");
end










-- 进阶/附加描述
Lua_PropertyDesItem = class("Lua_PropertyDesItem", Lua_DisplayObject);
function Lua_PropertyDesItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_PropertyDesItem:buildShowItem()
	self:superCall("buildShowItem");

	self.desTxt = UICreate.createLabel(self.content, "", 0, 0, 360, 0, 22);
	self.desTxt.pivot = Lua_WindowUtil.getPivot(1);
	self.desTxt.alignmentValue = 0;
	self.desTxt.verticalOverflowValue = 1;
	self.desTxt.colorStr = Lua_ColorDefine.transColorStr("DEE0E9");
	self.desTxt.clickScale = false;
	self.desTxt:addUrlClickFuntion(self, self.onClickFun);
end

function Lua_PropertyDesItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	self.desTxt.text = data;
	self.desTxt:resetSize();
end

function Lua_PropertyDesItem:onClickFun(urlStr)
	local arr = string.split(urlStr, "_");
	if arr and arr:getSize() > 2 then
		if not DataCenter.funcOpenData:isOpened(tonumber(arr[2]), true) then
			-- OperateAlert.showLangValue(460003);
			return;
		end
		DataCenter.funcPathUtil:gotoFunction(tonumber(arr[3]), true);
	end
end

function Lua_PropertyDesItem:getHeight()
	return self.desTxt.height + 5;
end

function Lua_PropertyDesItem:dispose()
	if self.desTxt ~= nil then
		self.desTxt:dispose();
		self.desTxt = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end










-- 带Icon的属性描述
Lua_CollectionAttrItem = class("Lua_CollectionAttrItem", Lua_DisplayObject);
function Lua_CollectionAttrItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_CollectionAttrItem:buildShowItem()
	self:superCall("buildShowItem");
	self.len = 0;
end

function Lua_CollectionAttrItem:setData(data)
	if data == nil then
		return;
	end

	local attrVo;
	local item;
	for k,v in pairs(data) do
		self.len = self.len + 1;

		attrVo = DataCenter.attributesUtil:createAttrVo(k);
		item = Lua_CollectionAttrSubItem.new(self.content);
		item:setEnable(true);
		item:setData(attrVo, v);
		item:setLocation(-165, -30 * (self.len - 1), 0);
	end
end

function Lua_CollectionAttrItem:getHeight()
	return self.len * 30 + 10;
end

function Lua_CollectionAttrItem:dispose()
	self:superCall("dispose");
end










-- 带Icon的属性描述
Lua_CollectionAttrSubItem = class("Lua_CollectionAttrSubItem", Lua_DisplayObject);
function Lua_CollectionAttrSubItem:ctor(p)
	self:superCall("ctor", p, "CollectionAttrSubItem_skin");
end

function Lua_CollectionAttrSubItem:setData(attrVo, value)
	if attrVo == nil then
		return;
	end
	self.attrIcon:setAltas("common_altas_2", attrVo.attr_icon_2);
	self.attrTxt.text = LanUtil.formateStr(460014, attrVo.show_name, value)
end