-- 藏宝柜
Lua_CollectionWindow = class("Lua_CollectionWindow.lua", Lua_Window);
function Lua_CollectionWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CollectionWindow";
	self.skinName = "CollectionWindow_skin";
	self.layer = MainWinDefine.MAIN_MENU_TOP_LAYER
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.showBackBtn = true;
	self.winBgPath = "/images/collection_cabinet/xui_cpg_bg_1.jpg";

	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_CollectionWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.showBg:SetDimensions(720, 1020 + self.adaptHeight);

	self.collectList = Lua_DragList.new(self.content, 699, 924 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.collectList.content.name = "collectList";
	self.collectList.tweenId = 2015;
	self.collectList:setListCell(Lua_CollectionItem, 699, 204, 1);
	self.collectList:setRectAnchor(1);
	self.collectList:setLocation(-1, -828 - self.adaptHeight / 2);

	self:addLuaEvent("UPDATE_COLLECTION_CABINET_INFO", self, self.updateCollectionInfo);
	-- Lua_ProxyManager.getProxy("Lua_CollectionProxy"):sCollectionInfo();
	self:updateCollectionInfo();
end

function Lua_CollectionWindow:onScreenResize()
	self:superCall("onScreenResize");

	self.showBg:SetDimensions(720, 1020 + self.adaptHeight);
	self.collectList:setContentRect(699, 924 + self.adaptHeight);
	self.collectList:setLocation(-1, -828 - self.adaptHeight / 2);
end

-- function Lua_CollectionWindow:onBackBtnClick()
-- 	DataCenter.funcPathUtil:gotoFunction(1001, true);
-- end

function Lua_CollectionWindow:updateCollectionInfo()
	local collectionArr = DataCenter.collectionData.collectionArr;
	local index = 1;
	local num = 0;
	local showList = {};
	for i = 1, collectionArr:getSize() do
		if showList[index] == nil then
			showList[index] = Array();
		end
		showList[index]:add(collectionArr[i]);

		num = num + 1;
		if num >= 3 then
			index = index + 1;
			num = 0;
		end
	end
	self.collectList:setArrayData(showList);
end

function Lua_CollectionWindow:dispose()
	if self.collectList ~= nil then
		self.collectList:dispose();
		self.collectList = nil;
	end
	self:superCall("dispose");
end

-- 检测引导数据
function Lua_CollectionWindow:checkWinGuide()
    self:superCall("checkWinGuide");
end

-- 引导同步
function Lua_CollectionWindow:updateGuide(guideId, info)
    if info == nil then
        return;
    end

    local operateVal = info.operateVal; -- 操作行为参数
    if operateVal == nil then
        return;
    end

	if operateVal == 1 then -- 藏品状态
		local collectionNum = info.collectionNum or 1;
		local collectionState = info.collectionState or 1;
		local arr = self.collectList.showDragDataList;
        local subCount;
        local raw, col;
        local curCount = 0;
        for i = 1, arr:getSize() do
        	local cellData = arr:getItem(i).data;
        	if cellData ~= nil then
        		subCount = cellData:getSize();
        		for j = 1, subCount do
        			local state = DataCenter.collectionData:getCollectionVoStateById(cellData[j]);
        			if state == collectionState then
        				curCount = curCount + 1;
        				if curCount == collectionNum then
        					raw = i;
        					col = j;
        					self.collectList:moveToIndex(raw, true);
        					break;
        				end
        			end
        		end
        	end

        	if raw and col and guideId then
        		self:delayCallGuide({raw, col, guideId})
        		break;
        	end
        end
	end
end

function Lua_CollectionWindow:delayCallGuide(param)
	local raw = param[1];
	local col = param[2];
	local guideId = param[3];
	if raw and col and guideId then
		local arr = self.collectList.showDragDataList;
		local item = arr:getItem(raw).cell;
		if item ~= nil then
			local subItem = item.itemArr[col];
			if subItem ~= nil then
				DataCenter.guideCommonData.guideSceneId = nil; -- 场景
				DataCenter.guideCommonData.guideClickObjPath = "content/"..self.collectList.content.name.."/ScrollContainer/Content/"..item.content.name.."/"..subItem.content.name.."/activeIcon";
    			Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
			end
		end
	end
end




--------------------------------------------------





Lua_CollectionItem = class("Lua_CollectionItem", Lua_ListCell)
function Lua_CollectionItem:ctor(p)
	self:superCall("ctor", p, "CollectionItem_skin");
end

function Lua_CollectionItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemArr = Array();
end

function Lua_CollectionItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local posX = {-219, 0, 219};
	local item;
	for i = 1, data:getSize() do
		item = self.itemArr[i];
		if item == nil then
			item = Lua_CollectionSingleItem.new(self.content);
			self.itemArr:add(item);
		end
		item:setData(data[i]);
		item.content.name = "Lua_CollectionSingleItem"..data[i];
		item:setLocation(posX[i], 10, 0);
	end
end

function Lua_CollectionItem:onPressClick()
	local item;
	local winPos = LuaUtil.getTouchPosInverseObj(self.mainContent);
	for i = 1, self._data:getSize() do
		item = self.itemArr[i];
		if item ~= nil and item:checkInBound(winPos.x, winPos.y) then
			item:onPressClick();
			break;
		end
	end
end

function Lua_CollectionItem:dispose()
	if self.itemArr ~= nil then
		self.itemArr:dispose();
		self.itemArr:clear();
		self.itemArr = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_CollectionSingleItem = class("Lua_CollectionSingleItem", Lua_ListCell);
function Lua_CollectionSingleItem:ctor(p)
	self:superCall("ctor", p, "CollectionSingleItem_skin");
end

function Lua_CollectionSingleItem:buildShowItem()
	self:superCall("buildShowItem");

	self.activeIcon:addClickFuntion(self, self.onActiveClick);
end

function Lua_CollectionSingleItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local collectVo = DataCenter.collectionData:getCollectionVo(data);
	self.itemIcon:setAltas(collectVo.atlas, collectVo.sprite);
	self.nameTxt.text = collectVo.name;
	
	local isAct = collectVo.is_have == 1 and collectVo.is_active == 0; -- 已拥有未激活
	self.itemIcon:setGray(collectVo.is_have == 0 or isAct);
	self.activeIcon:setEnable(isAct);

	local isDraw = collectVo.is_active == 1 and collectVo.is_draw_active_reward == 0; -- 已激活未领取
	self:showRedDot(isAct or isDraw);
end

-- 判断是否范围内
function Lua_CollectionSingleItem:checkInBound(posX, posY)
	local half_w = self.itemIcon.width / 2;
	local half_h = self.itemIcon.height / 2;
	self.minX = self.posX - half_w;
	self.maxX = self.posX + half_w;
	self.minY = self.posY - half_h;
	self.maxY = self.posY + half_h;

	if posX >= self.minX and posX <= self.maxX and posY >= self.minY and posY <= self.maxY then
		return true;
	end
	return false;
end

function Lua_CollectionSingleItem:onPressClick()
	Lua_WindowUtil.openWin("Lua_CollectionDetailWindow", Lua_WinParam.ACTION_OPEN, self._data);
end

function Lua_CollectionSingleItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(65, 60, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CollectionSingleItem:onActiveClick(go)
	Lua_ProxyManager.getProxy("Lua_CollectionProxy"):sActiveCollection(self._data);
end

function Lua_CollectionSingleItem:dispose()
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self._data = nil;

	self:superCall("dispose");
end